@@ -904,11 +904,11 @@ class BaseExperiment:
                             info = {val_metric : best_val}
         if not fetch_only_dir:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}' 
-            best_path_name = str(best_path).replace(".json", "")
-            ckpt_name = f'{ckpt_path}/{best_path_name}' 
+            ckpt_name = str(best_path).replace(".json", "")
             extension_candidates = [".ckpt", ".sav"]
             for extension_type in extension_candidates:
                 ckpt = ckpt_name + extension_type
+                print(ckpt)
                 if os.path.exists(ckpt):
                     ckpt_dir = ckpt
                     ckpt_extension_type = extension_type
@@ -925,7 +925,7 @@ class BaseExperiment:
             return best_ckpt, info
         else:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}'
-            ckpt_name = f'{ckpt_path}/{str(best_path).replace(".json", "")}' 
+            ckpt_name = str(best_path).replace(".json", "")
             extension_candidates = [".ckpt", ".sav"]
             for extension_type in extension_candidates:
                 ckpt = ckpt_name + extension_type
